import { __awaiter } from "tslib";
import { addProjectConfiguration, generateFiles, getWorkspaceLayout, names, offsetFromRoot, } from '@nrwl/devkit';
import * as path from 'path';
import { initPipenv } from './utils/init-pipenv';
function normalizeOptions(tree, options) {
    const name = names(options.name).fileName;
    const projectDirectory = options.directory
        ? `${names(options.directory).fileName}/${name}`
        : name;
    const projectName = projectDirectory.replace(new RegExp('/', 'g'), '-');
    const projectRoot = `${getWorkspaceLayout(tree).libsDir}/${projectDirectory}`;
    const parsedTags = options.tags
        ? options.tags.split(',').map((s) => s.trim())
        : [];
    return Object.assign(Object.assign({}, options), { projectName,
        projectRoot,
        projectDirectory,
        parsedTags });
}
function addFiles(tree, options) {
    const templateOptions = Object.assign(Object.assign(Object.assign({}, options), names(options.name)), { offsetFromRoot: offsetFromRoot(options.projectRoot), template: '' });
    generateFiles(tree, path.join(__dirname, 'files'), options.projectRoot, templateOptions);
}
// ? do I need python env files top level or in the app?
export default function (tree, options) {
    return __awaiter(this, void 0, void 0, function* () {
        const normalizedOptions = normalizeOptions(tree, options);
        addProjectConfiguration(tree, normalizedOptions.projectName, {
            root: normalizedOptions.projectRoot,
            projectType: 'library',
            sourceRoot: `${normalizedOptions.projectRoot}/src`,
            targets: {
                build: {
                    executor: '@daveholst/python-django:build',
                },
            },
            tags: normalizedOptions.parsedTags,
        });
        addFiles(tree, normalizedOptions);
        //! disable this as they are python files
        // await formatFiles(tree)
        // build the python env and install the files
        yield initPipenv();
    });
}
//# sourceMappingURL=generator.js.map